@@ -99,18 +99,6 @@ class MarkdownComment:
             if verbose:
                 self._comment_data.insert(0, '... trimmed for brevity...')
 
-    def clean_ascii_codes(self):
-        """Attempt to clean ascii colors and other escape codes from this comment. 
-
-        Returns:
-            MarkdownComment: Return self to allow a more fluent API -- i.e. enables chaining methods.
-        """
-        # from https://stackoverflow.com/a/14693789/1227086
-        # ansi_escape = re.compile(r'\x1B(?:[@-Z\\-_]|\[[0-?]*[ -/]*[@-~])')
-        ansi_escape = re.compile(r'\\u001b\[.*?m')
-        self._comment_data = [ansi_escape.sub('', line) for line in self._comment_data]
-        return self
-
     def add_build_annotation(self, jenkins_build_id=None, jenkins_build_url=None, playbook_limit=None,
                              build_status=None):
         """Add a (Jenkins) build annotation to the build. All arguments are optional, in which case a very simple
